NLSL: mtsdef.f90 Source File

NLSL

- Main Page
- Modules
- Data Types List
- Files

- File List
- File Members

mtsdef.f90
Go to the documentation of this file.
1 c NLSL Version 1.9.0 beta 2/12/15
2 c----------------------------------------------------------------------
3 c ====================
4 c module MTSDEF
5 c ====================
6 c
7 c Defines positions of elements of mts array used in lbasix and setmts
8 c routines
9 c
10 c mts(1) lemx Maximum even L
11 c mts(2) lomx Maximum odd L
12 c mts(3) kmn Minimum K (K<0 => jK = -1)
13 c mts(4 kmx Maximum K
14 c mts(5) mmn Minimum M (M<0 => jM = -1)
15 c mts(6) mmx Maximum M
16 c mts(7) ipnmx Maximum pI
17 c mts(8) ldelta L increment
18 c mts(9) kdelta K increment
19 c mts(10) ipsi0 Tilt angle flag
20 c mts(11) in2 Nuclear spin
21 c mts(12) jkmn Minimum jK
22 c mts(13) jmmn Minimum jM
23 c
24 c----------------------------------------------------------------------
25 c
26 module mtsdef
27 implicit none
28 c
29 integer, parameter ::
30 # nlemx=1,nlomx=2,nkmn=3,nkmx=4,nmmn=5,nmmx=6,nipnmx=7,
31 # nldel=8,nkdel=9,nipsi0=10,nin2=11,njkmn=12,njmmn=13,
32 # ntrc=7
33 c
34 end module mtsdef
mtsdef::nkmn
integer, parameter nkmn
Definition: mtsdef.f90:29
mtsdef::njkmn
integer, parameter njkmn
Definition: mtsdef.f90:29
mtsdef::ntrc
integer, parameter ntrc
Definition: mtsdef.f90:29
mtsdef::nmmx
integer, parameter nmmx
Definition: mtsdef.f90:29
mtsdef::nlemx
integer, parameter nlemx
Definition: mtsdef.f90:29
mtsdef::nipsi0
integer, parameter nipsi0
Definition: mtsdef.f90:29
mtsdef::nkdel
integer, parameter nkdel
Definition: mtsdef.f90:29
mtsdef::nin2
integer, parameter nin2
Definition: mtsdef.f90:29
mtsdef::nipnmx
integer, parameter nipnmx
Definition: mtsdef.f90:29
mtsdef::nmmn
integer, parameter nmmn
Definition: mtsdef.f90:29
mtsdef
Definition: mtsdef.f90:26
mtsdef::njmmn
integer, parameter njmmn
Definition: mtsdef.f90:29
mtsdef::nkmx
integer, parameter nkmx
Definition: mtsdef.f90:29
mtsdef::nlomx
integer, parameter nlomx
Definition: mtsdef.f90:29
mtsdef::nldel
integer, parameter nldel
Definition: mtsdef.f90:29